<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>ActionManager</name>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>&amp;Play</source>
        <translation>再生(&amp;Y)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>&amp;Pause</source>
        <translation>一時停止(&amp;P)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>&amp;Stop</source>
        <translation>終止(&amp;S)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>&amp;Previous</source>
        <translation>前の曲(&amp;R)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>&amp;Next</source>
        <translation>次の曲(&amp;N)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>&amp;Play/Pause</source>
        <translation>再生/一時停止(&amp;A)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>&amp;Jump to Track</source>
        <translation>指定のトラックへ移動(&amp;J)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>&amp;Repeat Playlist</source>
        <translation>プレイリストを繰り返す(&amp;L)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>&amp;Repeat Track</source>
        <translation>トラックを繰り返す(&amp;T)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>&amp;Shuffle</source>
        <translation>シャッフル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="48"/>
        <source>&amp;No Playlist Advance</source>
        <translation>次の曲に進まず終止(&amp;N)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="49"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="50"/>
        <source>&amp;Stop After Selected</source>
        <translation>選んだ曲を再生後に終止(&amp;S)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="52"/>
        <source>&amp;Clear Queue</source>
        <translation>キューを消去(&amp;C)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="52"/>
        <source>Alt+Q</source>
        <translation>Alt+Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Show Playlist</source>
        <translation>プレイリストを表示</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Show Equalizer</source>
        <translation>イコライザーを表示</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="56"/>
        <source>Always on Top</source>
        <translation>常に前面へ</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Put on All Workspaces</source>
        <translation>常に表示中のワークスペースに置く</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="58"/>
        <source>Double Size</source>
        <translation>倍サイズ</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="58"/>
        <source>Meta+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>&amp;Add File</source>
        <translation>ファイルを追加(&amp;F)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>&amp;Add Directory</source>
        <translation>ディレクトリを追加(&amp;D)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>&amp;Add Url</source>
        <translation>URL を追加(&amp;U)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="63"/>
        <source>&amp;Remove Selected</source>
        <translation>選択したものを除去(&amp;V)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="64"/>
        <source>Del</source>
        <translation>Delele</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="65"/>
        <source>&amp;Remove All</source>
        <translation>すべて除去(&amp;M)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="66"/>
        <source>&amp;Remove Unselected</source>
        <translation>選択外のものを除去(&amp;N)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="68"/>
        <source>Remove unavailable files</source>
        <translation>無効なファイルを除去</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Remove duplicates</source>
        <translation>重複分を除去</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>&amp;Queue Toggle</source>
        <translation>選んだプレイリストを キューに追加/キューから撤去</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>Invert Selection</source>
        <translation>選択範囲を反転</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>&amp;Select None</source>
        <translation>選択を解除(&amp;N)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>&amp;Select All</source>
        <translation>すべて選択(&amp;E)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="76"/>
        <source>&amp;View Track Details</source>
        <translation>トラックの詳細を表示(&amp;D)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="76"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>&amp;New List</source>
        <translation>新規リスト(&amp;W)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>&amp;Delete List</source>
        <translation>リストを削除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>&amp;Load List</source>
        <translation>リストを読込(&amp;L)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>&amp;Save List</source>
        <translation>リストを保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>Shift+S</source>
        <translation>Shift+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="82"/>
        <source>&amp;Select Next Playlist</source>
        <translation>次のプレイリストを選択(&amp;N)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>Ctrl+PgDown</source>
        <translation>Ctrl+PgDown</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>&amp;Select Previous Playlist</source>
        <translation>前のプレイリストを選択(&amp;P)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>Ctrl+PgUp</source>
        <translation>Ctrl+PgUp</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>&amp;Show Playlists</source>
        <translation>プレイリストを表示(&amp;H)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="87"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>&amp;Settings</source>
        <translation>設定(&amp;S)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>&amp;About</source>
        <translation>QMMP について(&amp;A)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;About Qt</source>
        <translation>Qt について(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>&amp;Exit</source>
        <translation>終了(&amp;X)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>EqWidget</name>
    <message>
        <location filename="../eqwidget.cpp" line="44"/>
        <source>Equalizer</source>
        <translation>イコライザー</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="157"/>
        <location filename="../eqwidget.cpp" line="178"/>
        <source>preset</source>
        <translation>プリセット</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="264"/>
        <source>&amp;Load/Delete</source>
        <translation>読み込み/削除(&amp;L)</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="266"/>
        <source>&amp;Save Preset</source>
        <translation>プリセットを保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="268"/>
        <source>&amp;Save Auto-load Preset</source>
        <translation>自動読み込みされたプリセットを保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="270"/>
        <source>&amp;Import</source>
        <translation>移入(&amp;I)</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="273"/>
        <source>&amp;Clear</source>
        <translation>消去(&amp;C)</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="302"/>
        <source>Saving Preset</source>
        <translation>プリセットを保存しています</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="303"/>
        <source>Preset name:</source>
        <translation>プリセット名:</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="304"/>
        <source>preset #</source>
        <translation>プリセット番号</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="395"/>
        <source>Import Preset</source>
        <translation>プリセットを移入</translation>
    </message>
</context>
<context>
    <name>HotkeyEditor</name>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="27"/>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="32"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="40"/>
        <source>Change shortcut...</source>
        <translation>ショートカットを変更...</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="55"/>
        <source>Playback</source>
        <translation>再生</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="61"/>
        <source>View</source>
        <translation>観容</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="67"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="73"/>
        <source>Misc</source>
        <translation>その他いろいろ</translation>
    </message>
</context>
<context>
    <name>MainDisplay</name>
    <message>
        <location filename="../display.cpp" line="57"/>
        <source>Previous</source>
        <translation>前の曲</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="61"/>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="64"/>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="67"/>
        <source>Stop</source>
        <translation>終止</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="70"/>
        <source>Next</source>
        <translation>次の曲</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="73"/>
        <source>Add file</source>
        <translation>ファイルを追加</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="80"/>
        <source>Equalizer</source>
        <translation>イコライザー</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="83"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="88"/>
        <source>Repeat playlist</source>
        <translation>プレイリストを繰り返し</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="91"/>
        <source>Shuffle</source>
        <translation>シャッフル</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="101"/>
        <source>Volume</source>
        <translation>音量</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="107"/>
        <source>Balance</source>
        <translation>バランス</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="296"/>
        <source>Volume: %1%</source>
        <translation>音量: %1%</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="300"/>
        <source>Balance: %1% right</source>
        <translation>バランス: %1% 右へ</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="302"/>
        <source>Balance: %1% left</source>
        <translation>バランス: %1% 左へ</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="304"/>
        <source>Balance: center</source>
        <translation>バランス: 中央に</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="315"/>
        <source>Seek to: %1</source>
        <translation>%1 に移動</translation>
    </message>
</context>
<context>
    <name>MainVisual</name>
    <message>
        <location filename="../mainvisual.cpp" line="243"/>
        <source>Visualization Mode</source>
        <translation>視覚効果モード</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="246"/>
        <source>Analyzer</source>
        <translation>スペクトルアナライザー</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="247"/>
        <source>Scope</source>
        <translation>オシロスコープ</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="248"/>
        <source>Off</source>
        <translation>使わない</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="255"/>
        <source>Analyzer Mode</source>
        <translation>アナライザーモード</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="258"/>
        <source>Normal</source>
        <translation>通常</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="259"/>
        <source>Fire</source>
        <translation>炎</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="260"/>
        <source>Vertical Lines</source>
        <translatorcomment>Winamp の表示どおりに</translatorcomment>
        <translation>線</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="261"/>
        <source>Lines</source>
        <translation>線</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="262"/>
        <source>Bars</source>
        <translation>点</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="275"/>
        <source>Peaks</source>
        <translation>ピーク表示</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="279"/>
        <source>Refresh Rate</source>
        <translation>再描画の頻度</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="282"/>
        <source>50 fps</source>
        <translation>50 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="283"/>
        <source>25 fps</source>
        <translation>25 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="284"/>
        <source>10 fps</source>
        <translation>10 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="285"/>
        <source>5 fps</source>
        <translation>5 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="292"/>
        <source>Analyzer Falloff</source>
        <translation>アナライザー減衰速度</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="295"/>
        <location filename="../mainvisual.cpp" line="309"/>
        <source>Slowest</source>
        <translation>さらに遅く</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="296"/>
        <location filename="../mainvisual.cpp" line="310"/>
        <source>Slow</source>
        <translation>遅く</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="297"/>
        <location filename="../mainvisual.cpp" line="311"/>
        <source>Medium</source>
        <translation>適度</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="298"/>
        <location filename="../mainvisual.cpp" line="312"/>
        <source>Fast</source>
        <translation>速く</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="299"/>
        <location filename="../mainvisual.cpp" line="313"/>
        <source>Fastest</source>
        <translation>さらに速く</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="306"/>
        <source>Peaks Falloff</source>
        <translation>ピーク減衰速度</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="319"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="320"/>
        <source>Transparent</source>
        <translation>透過させる</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Appearance</source>
        <translation>外観</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Shortcuts</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>View</source>
        <translation>観容</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Tools</source>
        <translation>ツール</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <location filename="../playlist.cpp" line="53"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="178"/>
        <source>&amp;Copy Selection To</source>
        <translation>選んだ曲目で新しいプレイリストを作る(&amp;C)</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="207"/>
        <source>Sort List</source>
        <translation>リストを並び換え</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="210"/>
        <location filename="../playlist.cpp" line="253"/>
        <source>By Title</source>
        <translation>タイトル順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="214"/>
        <location filename="../playlist.cpp" line="257"/>
        <source>By Album</source>
        <translation>アルバム名順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="218"/>
        <location filename="../playlist.cpp" line="261"/>
        <source>By Disc Number</source>
        <translation>ディスク番号順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="222"/>
        <location filename="../playlist.cpp" line="265"/>
        <source>By Artist</source>
        <translation>アーティスト名順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="226"/>
        <location filename="../playlist.cpp" line="269"/>
        <source>By Filename</source>
        <translation>ファイル名順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="230"/>
        <location filename="../playlist.cpp" line="273"/>
        <source>By Path + Filename</source>
        <translation>パスとファイル名の順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="234"/>
        <location filename="../playlist.cpp" line="277"/>
        <source>By Date</source>
        <translation>日付順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="238"/>
        <location filename="../playlist.cpp" line="281"/>
        <source>By Track Number</source>
        <translation>トラック番号順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="242"/>
        <location filename="../playlist.cpp" line="285"/>
        <source>By File Creation Date</source>
        <translation>ファイルの作成日順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="250"/>
        <source>Sort Selection</source>
        <translation>選択範囲内で並び換え</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="293"/>
        <source>Randomize List</source>
        <translation>リストを順不同に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="295"/>
        <source>Reverse List</source>
        <translation>リストを逆順に</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="302"/>
        <source>Actions</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="565"/>
        <source>&amp;New PlayList</source>
        <translation>新しいプレイリスト(&amp;N)</translation>
    </message>
</context>
<context>
    <name>PlayListBrowser</name>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="14"/>
        <source>Playlist Browser</source>
        <translation>プレイリストブラウザー</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="45"/>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="52"/>
        <location filename="../playlistbrowser.cpp" line="40"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="69"/>
        <location filename="../forms/playlistbrowser.ui" line="79"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playlistbrowser.cpp" line="39"/>
        <source>Rename</source>
        <translation>名前を変更</translation>
    </message>
</context>
<context>
    <name>PlayListSelector</name>
    <message>
        <location filename="../playlistselector.cpp" line="50"/>
        <source>&amp;Load</source>
        <translation>読込(&amp;L)</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="51"/>
        <source>&amp;Save As...</source>
        <translation>名前を付けて保存(&amp;A)...</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="53"/>
        <source>Rename</source>
        <translation>名前を変更</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="54"/>
        <source>&amp;Delete</source>
        <translation>削除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="125"/>
        <source>Rename Playlist</source>
        <translation>プレイリスト名を変更</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="125"/>
        <source>Playlist name:</source>
        <translation>プレイリスト名:</translation>
    </message>
</context>
<context>
    <name>PopupSettings</name>
    <message>
        <location filename="../forms/popupsettings.ui" line="14"/>
        <source>Popup Information Settings</source>
        <translation>吹き出し情報の設定</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="29"/>
        <source>Template</source>
        <translation>ひな形</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="58"/>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="65"/>
        <source>Insert</source>
        <translation>挿入</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="75"/>
        <source>Show cover</source>
        <translation>表紙画像を表示</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="89"/>
        <source>Cover size:</source>
        <translation>表紙画像の大きさ:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="115"/>
        <source>Transparency:</source>
        <translation>透明度:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="145"/>
        <source>Delay:</source>
        <translation>残映時間:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="178"/>
        <source>ms</source>
        <translation>ミリ秒</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="62"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="63"/>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="64"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="65"/>
        <source>Track number</source>
        <translation>トラック番号</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="66"/>
        <source>Two-digit track number</source>
        <translation>トラック番号 数字2桁</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="67"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="68"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="69"/>
        <source>Composer</source>
        <translation>作曲者</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="70"/>
        <source>Duration</source>
        <translation>再生時間</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="71"/>
        <source>Disc number</source>
        <translation>ディスク番号</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="72"/>
        <source>File name</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="73"/>
        <source>File path</source>
        <translation>ファイルパス</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="74"/>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="75"/>
        <source>Condition</source>
        <translation>定番</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../forms/preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>プリセットエディター</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="36"/>
        <source>Preset</source>
        <translation>プリセット</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="52"/>
        <source>Auto-preset</source>
        <translation>自動プリセット</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="77"/>
        <source>Load</source>
        <translation>読込</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="84"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation>ショートカットを変更</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>割り当てたい組み合わせキーを押します</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="52"/>
        <source>Clear</source>
        <translation>消去</translation>
    </message>
</context>
<context>
    <name>SkinnedFactory</name>
    <message>
        <location filename="../skinnedfactory.cpp" line="31"/>
        <source>Skinned User Interface</source>
        <translation>スキンつきユーザーインターフェイス</translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="44"/>
        <source>About Qmmp Skinned User Interface</source>
        <translation>QMMP スキンつきユーザーインターフェイスについて</translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="45"/>
        <source>Qmmp Skinned User Interface</source>
        <translation>QMMP スキンつきユーザーインターフェイス</translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="46"/>
        <source>Simple user interface with Winamp-2.x/XMMS skins support</source>
        <translation>WinAmp-2.x や XMMS1 用のスキンを介した簡素なユーザーインターフェイス</translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="47"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作者:
Владимир Кузнецов (Vladimir Kuznetsov) &lt;vovanec@gmail.com&gt;
Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="50"/>
        <source>Artwork:
Andrey Adreev &lt;andreev00@gmail.com&gt;</source>
        <translation>美術:
Андрей Андреев (Andrey Adreev) &lt;andreev00@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>SkinnedSettings</name>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="24"/>
        <source>Skins</source>
        <translation>スキン</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="55"/>
        <source>Add...</source>
        <translation>追加...</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="68"/>
        <source>Refresh</source>
        <translation>回復</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="89"/>
        <location filename="../forms/skinnedsettings.ui" line="95"/>
        <source>View</source>
        <translation>観容</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="101"/>
        <source>Hide on close</source>
        <translation>「閉じる」で隠す</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="108"/>
        <source>Start hidden</source>
        <translation>開始時に隠す</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="115"/>
        <source>Use skin cursors</source>
        <translation>スキンカーソルを使用</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="131"/>
        <source>Fonts</source>
        <translation>書体</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="149"/>
        <source>Player:</source>
        <translation>プレイヤー:</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="171"/>
        <location filename="../forms/skinnedsettings.ui" line="219"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="178"/>
        <location filename="../forms/skinnedsettings.ui" line="226"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="197"/>
        <source>Playlist:</source>
        <translation>プレイリスト:</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="233"/>
        <source>Use bitmap font if available</source>
        <translation>あればビットマップフォントを使用</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="243"/>
        <source>Transparency</source>
        <translation>透過効果</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="249"/>
        <source>Main window</source>
        <translation>メインウィンドウ</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="272"/>
        <location filename="../forms/skinnedsettings.ui" line="296"/>
        <location filename="../forms/skinnedsettings.ui" line="320"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="279"/>
        <source>Equalizer</source>
        <translation>イコライザー</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="303"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="344"/>
        <source>Miscellaneous</source>
        <translation>その他いろいろ</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="350"/>
        <source>Song Display</source>
        <translation>演目表示</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="356"/>
        <source>Show protocol</source>
        <translation>プロトコルを表示</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="363"/>
        <source>Show song numbers</source>
        <translation>曲番号つきで表示</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="387"/>
        <source>Show playlists</source>
        <translation>プレイリストを表示</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="394"/>
        <source>Show popup information</source>
        <translation>情報吹き出しを表示</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="406"/>
        <source>Edit template</source>
        <translation>ひな型を編集</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="430"/>
        <source>Playlist separator:</source>
        <translation>プレイリストの区切り:</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="468"/>
        <source>Show &apos;New Playlist&apos; button</source>
        <translation>&apos;新しいプレイリスト&apos;ボタンを表示</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="380"/>
        <source>Show anchor</source>
        <translation>アンカーを表示</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="373"/>
        <source>Align song numbers</source>
        <translation>曲番号のみを表示</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="101"/>
        <source>Select Skin Files</source>
        <translation>スキンファイルを選択</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="102"/>
        <source>Skin files</source>
        <translation>スキンファイル</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="150"/>
        <source>Unarchived skin</source>
        <translation>非書庫化スキン</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="181"/>
        <source>Archived skin</source>
        <translation>書庫化スキン</translation>
    </message>
</context>
<context>
    <name>TextScroller</name>
    <message>
        <location filename="../textscroller.cpp" line="53"/>
        <source>Autoscroll Songname</source>
        <translation>曲名を自動スクロール</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="54"/>
        <source>Transparent Background</source>
        <translation>背景を透過</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="123"/>
        <source>Buffering: %1%</source>
        <translation>バッファーへ先読み: %1%</translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="26"/>
        <source>Visualization</source>
        <translation>視覚効果</translation>
    </message>
</context>
</TS>
